@@ -20,18 +20,20 @@ class Engine:
             print(row)
     """
     
-    def __init__(self, debug=False, use_polars=True):
+    def __init__(self, debug=False, use_polars=True, first_match_only=False):
         """
         Initialize a new engine instance.
         
         Args:
             debug: If True, enables verbose logging of execution stages
             use_polars: If True, uses Polars for optimizations when available (default: True)
+            first_match_only: If True, only returns first match per left key in joins (prevents cartesian products from duplicates)
         """
         self._sources = {}
         self._source_metadata = {}
         self.debug = debug
         self.use_polars = use_polars
+        self.first_match_only = first_match_only
     
     def register(
         self,
@@ -120,4 +122,4 @@ class Engine:
             print(f"Building execution pipeline...\n")
         
         # Execute plan
-        return execute_plan(logical_plan, self._sources, self._source_metadata, debug=self.debug, use_polars=self.use_polars)
+        return execute_plan(logical_plan, self._sources, self._source_metadata, debug=self.debug, use_polars=self.use_polars, first_match_only=self.first_match_only)
