@@ -307,7 +307,8 @@ def _build_join_iterator(
     
     if use_merge_join:
         if debug:
-            print(f"      Using MERGE JOIN (sorted data)")
+            iterator_type = "MERGE JOIN"
+            print(f"      Using {iterator_type} (sorted data)")
         return MergeJoinIterator(
             left_iterator,
             right_source,
@@ -327,10 +328,11 @@ def _build_join_iterator(
         if (MMAP_AVAILABLE and MmapLookupJoinIterator is not None and 
             right_table_filename):
             if debug:
+                iterator_type = "MMAP LOOKUP JOIN"
                 if required_columns:
-                    print(f"      Using MMAP LOOKUP JOIN (low memory, columns: {len(required_columns)})...")
+                    print(f"      Using {iterator_type} (low memory, columns: {len(required_columns)})...")
                 else:
-                    print(f"      Using MMAP LOOKUP JOIN (low memory, position-based index)...")
+                    print(f"      Using {iterator_type} (low memory, position-based index)...")
             try:
                 return MmapLookupJoinIterator(
                     left_iterator,
@@ -358,10 +360,13 @@ def _build_join_iterator(
         if (use_polars and POLARS_AVAILABLE and 
             should_use_polars(right_source, threshold=10000)):
             if debug:
+                iterator_type = "POLARS LOOKUP JOIN"
                 if required_columns:
-                    print(f"      Using POLARS LOOKUP JOIN (fast, columns: {len(required_columns)})...")
+                    print(f"      Using {iterator_type} (fast, columns: {len(required_columns)})...")
                 else:
-                    print(f"      Using POLARS LOOKUP JOIN (fast, vectorized)...")
+                    print(f"      Using {iterator_type} (fast, vectorized)...")
+                if first_match_only:
+                    print(f"      ⚡ First-match-only mode enabled")
             try:
                 return PolarsLookupJoinIterator(
                     left_iterator,
@@ -373,7 +378,8 @@ def _build_join_iterator(
                     join_info.alias,
                     batch_size=10000,
                     required_columns=required_columns,
-                    debug=debug
+                    debug=debug,
+                    first_match_only=first_match_only
                 )
             except Exception as e:
                 if debug:
@@ -382,10 +388,13 @@ def _build_join_iterator(
                 pass
         
         if debug:
+            iterator_type = "LOOKUP JOIN (Python)"
             if required_columns:
-                print(f"      Using LOOKUP JOIN (building index, columns: {len(required_columns)})...")
+                print(f"      Using {iterator_type} (building index, columns: {len(required_columns)})...")
             else:
-                print(f"      Using LOOKUP JOIN (building index...)")
+                print(f"      Using {iterator_type} (building index...)")
+            if first_match_only:
+                print(f"      ⚡ First-match-only mode enabled")
         return LookupJoinIterator(
             left_iterator,
             right_source,
